==> knative-model-6.3.1-sources.jar: io/fabric8/knative/messaging/v1/ChannelSpecFluentImpl.java <==
package io.fabric8.knative.messaging.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.SuppressWarnings;
import io.fabric8.knative.internal.eventing.pkg.apis.duck.v1.DeliverySpecFluentImpl;
import io.fabric8.knative.internal.eventing.pkg.apis.duck.v1.SubscriberSpecFluentImpl;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.knative.internal.eventing.pkg.apis.duck.v1.SubscriberSpec;
import java.util.function.Predicate;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.knative.internal.eventing.pkg.apis.duck.v1.DeliverySpec;
import java.lang.Integer;
import io.fabric8.knative.internal.eventing.pkg.apis.duck.v1.DeliverySpecBuilder;
import io.fabric8.knative.internal.eventing.pkg.apis.duck.v1.SubscriberSpecBuilder;
import java.util.Collection;
import java.lang.Object;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ChannelSpecFluentImpl<A extends ChannelSpecFluent<A>> extends BaseFluent<A> implements ChannelSpecFluent<A>{
  public ChannelSpecFluentImpl() {
  }
  public ChannelSpecFluentImpl(ChannelSpec instance) {
    this.withChannelTemplate(instance.getChannelTemplate()); 
    this.withDelivery(instance.getDelivery()); 
    this.withSubscribers(instance.getSubscribers()); 
  }
  private ChannelTemplateSpecBuilder channelTemplate;
  private DeliverySpecBuilder delivery;
  private ArrayList<SubscriberSpecBuilder> subscribers = new ArrayList<SubscriberSpecBuilder>();
  
  /**
   * This method has been deprecated, please use method buildChannelTemplate instead.
   * @return The buildable object.
   */
  @Deprecated
  public ChannelTemplateSpec getChannelTemplate() {
    return this.channelTemplate!=null ?this.channelTemplate.build():null;
  }
  public ChannelTemplateSpec buildChannelTemplate() {
    return this.channelTemplate!=null ?this.channelTemplate.build():null;
  }
  public A withChannelTemplate(ChannelTemplateSpec channelTemplate) {
    _visitables.get("channelTemplate").remove(this.channelTemplate);
    if (channelTemplate!=null){ this.channelTemplate= new ChannelTemplateSpecBuilder(channelTemplate); _visitables.get("channelTemplate").add(this.channelTemplate);} else { this.channelTemplate = null; _visitables.get("channelTemplate").remove(this.channelTemplate); } return (A) this;
  }
  public Boolean hasChannelTemplate() {
    return this.channelTemplate != null;
  }
  public ChannelSpecFluent.ChannelTemplateNested<A> withNewChannelTemplate() {
    return new ChannelSpecFluentImpl.ChannelTemplateNestedImpl();
  }
  public ChannelSpecFluent.ChannelTemplateNested<A> withNewChannelTemplateLike(ChannelTemplateSpec item) {
    return new ChannelSpecFluentImpl.ChannelTemplateNestedImpl(item);
  }
  public ChannelSpecFluent.ChannelTemplateNested<A> editChannelTemplate() {
    return withNewChannelTemplateLike(getChannelTemplate());
  }
  public ChannelSpecFluent.ChannelTemplateNested<A> editOrNewChannelTemplate() {
    return withNewChannelTemplateLike(getChannelTemplate() != null ? getChannelTemplate(): new ChannelTemplateSpecBuilder().build());
  }
  public ChannelSpecFluent.ChannelTemplateNested<A> editOrNewChannelTemplateLike(ChannelTemplateSpec item) {
    return withNewChannelTemplateLike(getChannelTemplate() != null ? getChannelTemplate(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildDelivery instead.
   * @return The buildable object.
   */
  @Deprecated
  public DeliverySpec getDelivery() {
    return this.delivery!=null ?this.delivery.build():null;
  }
  public DeliverySpec buildDelivery() {
    return this.delivery!=null ?this.delivery.build():null;
  }
  public A withDelivery(DeliverySpec delivery) {
    _visitables.get("delivery").remove(this.delivery);
    if (delivery!=null){ this.delivery= new DeliverySpecBuilder(delivery); _visitables.get("delivery").add(this.delivery);} else { this.delivery = null; _visitables.get("delivery").remove(this.delivery); } return (A) this;
  }
  public Boolean hasDelivery() {
    return this.delivery != null;
  }
  public ChannelSpecFluent.DeliveryNested<A> withNewDelivery() {
    return new ChannelSpecFluentImpl.DeliveryNestedImpl();
  }
  public ChannelSpecFluent.DeliveryNested<A> withNewDeliveryLike(DeliverySpec item) {
    return new ChannelSpecFluentImpl.DeliveryNestedImpl(item);
  }
  public ChannelSpecFluent.DeliveryNested<A> editDelivery() {
    return withNewDeliveryLike(getDelivery());
  }
  public ChannelSpecFluent.DeliveryNested<A> editOrNewDelivery() {
    return withNewDeliveryLike(getDelivery() != null ? getDelivery(): new DeliverySpecBuilder().build());
  }
  public ChannelSpecFluent.DeliveryNested<A> editOrNewDeliveryLike(DeliverySpec item) {
    return withNewDeliveryLike(getDelivery() != null ? getDelivery(): item);
  }
  public A addToSubscribers(Integer index,SubscriberSpec item) {
    if (this.subscribers == null) {this.subscribers = new ArrayList<SubscriberSpecBuilder>();}
    SubscriberSpecBuilder builder = new SubscriberSpecBuilder(item);_visitables.get("subscribers").add(index >= 0 ? index : _visitables.get("subscribers").size(), builder);this.subscribers.add(index >= 0 ? index : subscribers.size(), builder); return (A)this;
  }
  public A setToSubscribers(Integer index,SubscriberSpec item) {
    if (this.subscribers == null) {this.subscribers = new ArrayList<SubscriberSpecBuilder>();}
    SubscriberSpecBuilder builder = new SubscriberSpecBuilder(item);
    if (index < 0 || index >= _visitables.get("subscribers").size()) { _visitables.get("subscribers").add(builder); } else { _visitables.get("subscribers").set(index, builder);}
    if (index < 0 || index >= subscribers.size()) { subscribers.add(builder); } else { subscribers.set(index, builder);}
     return (A)this;
  }
  public A addToSubscribers(io.fabric8.knative.internal.eventing.pkg.apis.duck.v1.SubscriberSpec... items) {
    if (this.subscribers == null) {this.subscribers = new ArrayList<SubscriberSpecBuilder>();}
    for (SubscriberSpec item : items) {SubscriberSpecBuilder builder = new SubscriberSpecBuilder(item);_visitables.get("subscribers").add(builder);this.subscribers.add(builder);} return (A)this;
  }
  public A addAllToSubscribers(Collection<SubscriberSpec> items) {
    if (this.subscribers == null) {this.subscribers = new ArrayList<SubscriberSpecBuilder>();}
    for (SubscriberSpec item : items) {SubscriberSpecBuilder builder = new SubscriberSpecBuilder(item);_visitables.get("subscribers").add(builder);this.subscribers.add(builder);} return (A)this;
  }
  public A removeFromSubscribers(io.fabric8.knative.internal.eventing.pkg.apis.duck.v1.SubscriberSpec... items) {
    for (SubscriberSpec item : items) {SubscriberSpecBuilder builder = new SubscriberSpecBuilder(item);_visitables.get("subscribers").remove(builder);if (this.subscribers != null) {this.subscribers.remove(builder);}} return (A)this;
  }
  public A removeAllFromSubscribers(Collection<SubscriberSpec> items) {
    for (SubscriberSpec item : items) {SubscriberSpecBuilder builder = new SubscriberSpecBuilder(item);_visitables.get("subscribers").remove(builder);if (this.subscribers != null) {this.subscribers.remove(builder);}} return (A)this;
  }
  public A removeMatchingFromSubscribers(Predicate<SubscriberSpecBuilder> predicate) {
    if (subscribers == null) return (A) this;
    final Iterator<SubscriberSpecBuilder> each = subscribers.iterator();
    final List visitables = _visitables.get("subscribers");
    while (each.hasNext()) {
      SubscriberSpecBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  
  /**
   * This method has been deprecated, please use method buildSubscribers instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<SubscriberSpec> getSubscribers() {
    return subscribers != null ? build(subscribers) : null;
  }
  public List<SubscriberSpec> buildSubscribers() {
    return subscribers != null ? build(subscribers) : null;
  }
  public SubscriberSpec buildSubscriber(Integer index) {
    return this.subscribers.get(index).build();
  }
  public SubscriberSpec buildFirstSubscriber() {
    return this.subscribers.get(0).build();
  }
  public SubscriberSpec buildLastSubscriber() {
    return this.subscribers.get(subscribers.size() - 1).build();
  }
  public SubscriberSpec buildMatchingSubscriber(Predicate<SubscriberSpecBuilder> predicate) {
    for (SubscriberSpecBuilder item: subscribers) { if(predicate.test(item)){ return item.build();} } return null;
  }
  public Boolean hasMatchingSubscriber(Predicate<SubscriberSpecBuilder> predicate) {
    for (SubscriberSpecBuilder item: subscribers) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withSubscribers(List<SubscriberSpec> subscribers) {
    if (this.subscribers != null) { _visitables.get("subscribers").removeAll(this.subscribers);}
    if (subscribers != null) {this.subscribers = new ArrayList(); for (SubscriberSpec item : subscribers){this.addToSubscribers(item);}} else { this.subscribers = null;} return (A) this;
  }
  public A withSubscribers(io.fabric8.knative.internal.eventing.pkg.apis.duck.v1.SubscriberSpec... subscribers) {
    if (this.subscribers != null) {this.subscribers.clear();}
    if (subscribers != null) {for (SubscriberSpec item :subscribers){ this.addToSubscribers(item);}} return (A) this;
  }
  public Boolean hasSubscribers() {
    return subscribers != null && !subscribers.isEmpty();
  }
  public ChannelSpecFluent.SubscribersNested<A> addNewSubscriber() {
    return new ChannelSpecFluentImpl.SubscribersNestedImpl();
  }
  public ChannelSpecFluent.SubscribersNested<A> addNewSubscriberLike(SubscriberSpec item) {
    return new ChannelSpecFluentImpl.SubscribersNestedImpl(-1, item);
  }
  public ChannelSpecFluent.SubscribersNested<A> setNewSubscriberLike(Integer index,SubscriberSpec item) {
    return new ChannelSpecFluentImpl.SubscribersNestedImpl(index, item);
  }
  public ChannelSpecFluent.SubscribersNested<A> editSubscriber(Integer index) {
    if (subscribers.size() <= index) throw new RuntimeException("Can't edit subscribers. Index exceeds size.");
    return setNewSubscriberLike(index, buildSubscriber(index));
  }
  public ChannelSpecFluent.SubscribersNested<A> editFirstSubscriber() {
    if (subscribers.size() == 0) throw new RuntimeException("Can't edit first subscribers. The list is empty.");
    return setNewSubscriberLike(0, buildSubscriber(0));
  }
  public ChannelSpecFluent.SubscribersNested<A> editLastSubscriber() {
    int index = subscribers.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last subscribers. The list is empty.");
    return setNewSubscriberLike(index, buildSubscriber(index));
  }
  public ChannelSpecFluent.SubscribersNested<A> editMatchingSubscriber(Predicate<SubscriberSpecBuilder> predicate) {
    int index = -1;
    for (int i=0;i<subscribers.size();i++) { 
    if (predicate.test(subscribers.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching subscribers. No match found.");
    return setNewSubscriberLike(index, buildSubscriber(index));
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ChannelSpecFluentImpl that = (ChannelSpecFluentImpl) o;
    if (channelTemplate != null ? !channelTemplate.equals(that.channelTemplate) :that.channelTemplate != null) return false;
    if (delivery != null ? !delivery.equals(that.delivery) :that.delivery != null) return false;
    if (subscribers != null ? !subscribers.equals(that.subscribers) :that.subscribers != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(channelTemplate,  delivery,  subscribers,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (channelTemplate != null) { sb.append("channelTemplate:"); sb.append(channelTemplate + ","); }
    if (delivery != null) { sb.append("delivery:"); sb.append(delivery + ","); }
    if (subscribers != null && !subscribers.isEmpty()) { sb.append("subscribers:"); sb.append(subscribers); }
    sb.append("}");
    return sb.toString();
  }
  class ChannelTemplateNestedImpl<N> extends ChannelTemplateSpecFluentImpl<ChannelSpecFluent.ChannelTemplateNested<N>> implements ChannelSpecFluent.ChannelTemplateNested<N>,Nested<N>{
    ChannelTemplateNestedImpl(ChannelTemplateSpec item) {
      this.builder = new ChannelTemplateSpecBuilder(this, item);
    }
    ChannelTemplateNestedImpl() {
      this.builder = new ChannelTemplateSpecBuilder(this);
    }
    ChannelTemplateSpecBuilder builder;
    public N and() {
      return (N) ChannelSpecFluentImpl.this.withChannelTemplate(builder.build());
    }
    public N endChannelTemplate() {
      return and();
    }
    
  }
  class DeliveryNestedImpl<N> extends DeliverySpecFluentImpl<ChannelSpecFluent.DeliveryNested<N>> implements ChannelSpecFluent.DeliveryNested<N>,Nested<N>{
    DeliveryNestedImpl(DeliverySpec item) {
      this.builder = new DeliverySpecBuilder(this, item);
    }
    DeliveryNestedImpl() {
      this.builder = new DeliverySpecBuilder(this);
    }
    DeliverySpecBuilder builder;
    public N and() {
      return (N) ChannelSpecFluentImpl.this.withDelivery(builder.build());
    }
    public N endDelivery() {
      return and();
    }
    
  }
  class SubscribersNestedImpl<N> extends SubscriberSpecFluentImpl<ChannelSpecFluent.SubscribersNested<N>> implements ChannelSpecFluent.SubscribersNested<N>,Nested<N>{
    SubscribersNestedImpl(Integer index,SubscriberSpec item) {
      this.index = index;
      this.builder = new SubscriberSpecBuilder(this, item);
    }
    SubscribersNestedImpl() {
      this.index = -1;
      this.builder = new SubscriberSpecBuilder(this);
    }
    SubscriberSpecBuilder builder;
    Integer index;
    public N and() {
      return (N) ChannelSpecFluentImpl.this.setToSubscribers(index,builder.build());
    }
    public N endSubscriber() {
      return and();
    }
    
  }
  
}

==> knative-model-6.7.1-sources.jar: io/fabric8/knative/messaging/v1/ChannelSpecFluentImpl.java <==
package io.fabric8.knative.messaging.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.SuppressWarnings;
import io.fabric8.knative.internal.eventing.pkg.apis.duck.v1.DeliverySpecFluentImpl;
import io.fabric8.knative.internal.eventing.pkg.apis.duck.v1.SubscriberSpecFluentImpl;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.knative.internal.eventing.pkg.apis.duck.v1.SubscriberSpec;
import java.util.function.Predicate;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.knative.internal.eventing.pkg.apis.duck.v1.DeliverySpec;
import io.fabric8.knative.internal.eventing.pkg.apis.duck.v1.DeliverySpecBuilder;
import io.fabric8.knative.internal.eventing.pkg.apis.duck.v1.SubscriberSpecBuilder;
import java.util.Collection;
import java.lang.Object;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ChannelSpecFluentImpl<A extends ChannelSpecFluent<A>> extends BaseFluent<A> implements ChannelSpecFluent<A>{
  public ChannelSpecFluentImpl() {
  }
  public ChannelSpecFluentImpl(ChannelSpec instance) {
    if (instance != null) {
      this.withChannelTemplate(instance.getChannelTemplate());
      this.withDelivery(instance.getDelivery());
      this.withSubscribers(instance.getSubscribers());
    }
  }
  private ChannelTemplateSpecBuilder channelTemplate;
  private DeliverySpecBuilder delivery;
  private ArrayList<SubscriberSpecBuilder> subscribers = new ArrayList<SubscriberSpecBuilder>();
  
  /**
   * This method has been deprecated, please use method buildChannelTemplate instead.
   * @return The buildable object.
   */
  @Deprecated
  public ChannelTemplateSpec getChannelTemplate() {
    return this.channelTemplate!=null ?this.channelTemplate.build():null;
  }
  public ChannelTemplateSpec buildChannelTemplate() {
    return this.channelTemplate!=null ?this.channelTemplate.build():null;
  }
  public A withChannelTemplate(ChannelTemplateSpec channelTemplate) {
    _visitables.get("channelTemplate").remove(this.channelTemplate);
    if (channelTemplate!=null){ this.channelTemplate= new ChannelTemplateSpecBuilder(channelTemplate); _visitables.get("channelTemplate").add(this.channelTemplate);} else { this.channelTemplate = null; _visitables.get("channelTemplate").remove(this.channelTemplate); } return (A) this;
  }
  public Boolean hasChannelTemplate() {
    return this.channelTemplate != null;
  }
  public ChannelSpecFluentImpl.ChannelTemplateNested<A> withNewChannelTemplate() {
    return new ChannelSpecFluentImpl.ChannelTemplateNestedImpl();
  }
  public ChannelSpecFluentImpl.ChannelTemplateNested<A> withNewChannelTemplateLike(ChannelTemplateSpec item) {
    return new ChannelSpecFluentImpl.ChannelTemplateNestedImpl(item);
  }
  public ChannelSpecFluentImpl.ChannelTemplateNested<A> editChannelTemplate() {
    return withNewChannelTemplateLike(getChannelTemplate());
  }
  public ChannelSpecFluentImpl.ChannelTemplateNested<A> editOrNewChannelTemplate() {
    return withNewChannelTemplateLike(getChannelTemplate() != null ? getChannelTemplate(): new ChannelTemplateSpecBuilder().build());
  }
  public ChannelSpecFluentImpl.ChannelTemplateNested<A> editOrNewChannelTemplateLike(ChannelTemplateSpec item) {
    return withNewChannelTemplateLike(getChannelTemplate() != null ? getChannelTemplate(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildDelivery instead.
   * @return The buildable object.
   */
  @Deprecated
  public DeliverySpec getDelivery() {
    return this.delivery!=null ?this.delivery.build():null;
  }
  public DeliverySpec buildDelivery() {
    return this.delivery!=null ?this.delivery.build():null;
  }
  public A withDelivery(DeliverySpec delivery) {
    _visitables.get("delivery").remove(this.delivery);
    if (delivery!=null){ this.delivery= new DeliverySpecBuilder(delivery); _visitables.get("delivery").add(this.delivery);} else { this.delivery = null; _visitables.get("delivery").remove(this.delivery); } return (A) this;
  }
  public Boolean hasDelivery() {
    return this.delivery != null;
  }
  public ChannelSpecFluentImpl.DeliveryNested<A> withNewDelivery() {
    return new ChannelSpecFluentImpl.DeliveryNestedImpl();
  }
  public ChannelSpecFluentImpl.DeliveryNested<A> withNewDeliveryLike(DeliverySpec item) {
    return new ChannelSpecFluentImpl.DeliveryNestedImpl(item);
  }
  public ChannelSpecFluentImpl.DeliveryNested<A> editDelivery() {
    return withNewDeliveryLike(getDelivery());
  }
  public ChannelSpecFluentImpl.DeliveryNested<A> editOrNewDelivery() {
    return withNewDeliveryLike(getDelivery() != null ? getDelivery(): new DeliverySpecBuilder().build());
  }
  public ChannelSpecFluentImpl.DeliveryNested<A> editOrNewDeliveryLike(DeliverySpec item) {
    return withNewDeliveryLike(getDelivery() != null ? getDelivery(): item);
  }
  public A addToSubscribers(int index,SubscriberSpec item) {
    if (this.subscribers == null) {this.subscribers = new ArrayList<SubscriberSpecBuilder>();}
    SubscriberSpecBuilder builder = new SubscriberSpecBuilder(item);
    if (index < 0 || index >= subscribers.size()) { _visitables.get("subscribers").add(builder); subscribers.add(builder); } else { _visitables.get("subscribers").add(index, builder); subscribers.add(index, builder);}
    return (A)this;
  }
  public A setToSubscribers(int index,SubscriberSpec item) {
    if (this.subscribers == null) {this.subscribers = new ArrayList<SubscriberSpecBuilder>();}
    SubscriberSpecBuilder builder = new SubscriberSpecBuilder(item);
    if (index < 0 || index >= subscribers.size()) { _visitables.get("subscribers").add(builder); subscribers.add(builder); } else { _visitables.get("subscribers").set(index, builder); subscribers.set(index, builder);}
    return (A)this;
  }
  public A addToSubscribers(io.fabric8.knative.internal.eventing.pkg.apis.duck.v1.SubscriberSpec... items) {
    if (this.subscribers == null) {this.subscribers = new ArrayList<SubscriberSpecBuilder>();}
    for (SubscriberSpec item : items) {SubscriberSpecBuilder builder = new SubscriberSpecBuilder(item);_visitables.get("subscribers").add(builder);this.subscribers.add(builder);} return (A)this;
  }
  public A addAllToSubscribers(Collection<SubscriberSpec> items) {
    if (this.subscribers == null) {this.subscribers = new ArrayList<SubscriberSpecBuilder>();}
    for (SubscriberSpec item : items) {SubscriberSpecBuilder builder = new SubscriberSpecBuilder(item);_visitables.get("subscribers").add(builder);this.subscribers.add(builder);} return (A)this;
  }
  public A removeFromSubscribers(io.fabric8.knative.internal.eventing.pkg.apis.duck.v1.SubscriberSpec... items) {
    for (SubscriberSpec item : items) {SubscriberSpecBuilder builder = new SubscriberSpecBuilder(item);_visitables.get("subscribers").remove(builder);if (this.subscribers != null) {this.subscribers.remove(builder);}} return (A)this;
  }
  public A removeAllFromSubscribers(Collection<SubscriberSpec> items) {
    for (SubscriberSpec item : items) {SubscriberSpecBuilder builder = new SubscriberSpecBuilder(item);_visitables.get("subscribers").remove(builder);if (this.subscribers != null) {this.subscribers.remove(builder);}} return (A)this;
  }
  public A removeMatchingFromSubscribers(Predicate<SubscriberSpecBuilder> predicate) {
    if (subscribers == null) return (A) this;
    final Iterator<SubscriberSpecBuilder> each = subscribers.iterator();
    final List visitables = _visitables.get("subscribers");
    while (each.hasNext()) {
      SubscriberSpecBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  
  /**
   * This method has been deprecated, please use method buildSubscribers instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<SubscriberSpec> getSubscribers() {
    return subscribers != null ? build(subscribers) : null;
  }
  public List<SubscriberSpec> buildSubscribers() {
    return subscribers != null ? build(subscribers) : null;
  }
  public SubscriberSpec buildSubscriber(int index) {
    return this.subscribers.get(index).build();
  }
  public SubscriberSpec buildFirstSubscriber() {
    return this.subscribers.get(0).build();
  }
  public SubscriberSpec buildLastSubscriber() {
    return this.subscribers.get(subscribers.size() - 1).build();
  }
  public SubscriberSpec buildMatchingSubscriber(Predicate<SubscriberSpecBuilder> predicate) {
    for (SubscriberSpecBuilder item: subscribers) { if(predicate.test(item)){ return item.build();} } return null;
  }
  public Boolean hasMatchingSubscriber(Predicate<SubscriberSpecBuilder> predicate) {
    for (SubscriberSpecBuilder item: subscribers) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withSubscribers(List<SubscriberSpec> subscribers) {
    if (this.subscribers != null) { _visitables.get("subscribers").clear();}
    if (subscribers != null) {this.subscribers = new ArrayList(); for (SubscriberSpec item : subscribers){this.addToSubscribers(item);}} else { this.subscribers = null;} return (A) this;
  }
  public A withSubscribers(io.fabric8.knative.internal.eventing.pkg.apis.duck.v1.SubscriberSpec... subscribers) {
    if (this.subscribers != null) {this.subscribers.clear(); _visitables.remove("subscribers"); }
    if (subscribers != null) {for (SubscriberSpec item :subscribers){ this.addToSubscribers(item);}} return (A) this;
  }
  public Boolean hasSubscribers() {
    return subscribers != null && !subscribers.isEmpty();
  }
  public ChannelSpecFluentImpl.SubscribersNested<A> addNewSubscriber() {
    return new ChannelSpecFluentImpl.SubscribersNestedImpl();
  }
  public ChannelSpecFluentImpl.SubscribersNested<A> addNewSubscriberLike(SubscriberSpec item) {
    return new ChannelSpecFluentImpl.SubscribersNestedImpl(-1, item);
  }
  public ChannelSpecFluentImpl.SubscribersNested<A> setNewSubscriberLike(int index,SubscriberSpec item) {
    return new ChannelSpecFluentImpl.SubscribersNestedImpl(index, item);
  }
  public ChannelSpecFluentImpl.SubscribersNested<A> editSubscriber(int index) {
    if (subscribers.size() <= index) throw new RuntimeException("Can't edit subscribers. Index exceeds size.");
    return setNewSubscriberLike(index, buildSubscriber(index));
  }
  public ChannelSpecFluentImpl.SubscribersNested<A> editFirstSubscriber() {
    if (subscribers.size() == 0) throw new RuntimeException("Can't edit first subscribers. The list is empty.");
    return setNewSubscriberLike(0, buildSubscriber(0));
  }
  public ChannelSpecFluentImpl.SubscribersNested<A> editLastSubscriber() {
    int index = subscribers.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last subscribers. The list is empty.");
    return setNewSubscriberLike(index, buildSubscriber(index));
  }
  public ChannelSpecFluentImpl.SubscribersNested<A> editMatchingSubscriber(Predicate<SubscriberSpecBuilder> predicate) {
    int index = -1;
    for (int i=0;i<subscribers.size();i++) { 
    if (predicate.test(subscribers.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching subscribers. No match found.");
    return setNewSubscriberLike(index, buildSubscriber(index));
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ChannelSpecFluentImpl that = (ChannelSpecFluentImpl) o;
    if (!java.util.Objects.equals(channelTemplate, that.channelTemplate)) return false;

    if (!java.util.Objects.equals(delivery, that.delivery)) return false;

    if (!java.util.Objects.equals(subscribers, that.subscribers)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(channelTemplate,  delivery,  subscribers,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (channelTemplate != null) { sb.append("channelTemplate:"); sb.append(channelTemplate + ","); }
    if (delivery != null) { sb.append("delivery:"); sb.append(delivery + ","); }
    if (subscribers != null) { sb.append("subscribers:"); sb.append(subscribers); }
    sb.append("}");
    return sb.toString();
  }
  class ChannelTemplateNestedImpl<N> extends ChannelTemplateSpecFluentImpl<ChannelSpecFluentImpl.ChannelTemplateNested<N>> implements ChannelSpecFluentImpl.ChannelTemplateNested<N>,Nested<N>{
    ChannelTemplateNestedImpl(ChannelTemplateSpec item) {
      this.builder = new ChannelTemplateSpecBuilder(this, item);
    }
    ChannelTemplateNestedImpl() {
      this.builder = new ChannelTemplateSpecBuilder(this);
    }
    ChannelTemplateSpecBuilder builder;
    public N and() {
      return (N) ChannelSpecFluentImpl.this.withChannelTemplate(builder.build());
    }
    public N endChannelTemplate() {
      return and();
    }
    
  }
  class DeliveryNestedImpl<N> extends DeliverySpecFluentImpl<ChannelSpecFluentImpl.DeliveryNested<N>> implements ChannelSpecFluentImpl.DeliveryNested<N>,Nested<N>{
    DeliveryNestedImpl(DeliverySpec item) {
      this.builder = new DeliverySpecBuilder(this, item);
    }
    DeliveryNestedImpl() {
      this.builder = new DeliverySpecBuilder(this);
    }
    DeliverySpecBuilder builder;
    public N and() {
      return (N) ChannelSpecFluentImpl.this.withDelivery(builder.build());
    }
    public N endDelivery() {
      return and();
    }
    
  }
  class SubscribersNestedImpl<N> extends SubscriberSpecFluentImpl<ChannelSpecFluentImpl.SubscribersNested<N>> implements ChannelSpecFluentImpl.SubscribersNested<N>,Nested<N>{
    SubscribersNestedImpl(int index,SubscriberSpec item) {
      this.index = index;
      this.builder = new SubscriberSpecBuilder(this, item);
    }
    SubscribersNestedImpl() {
      this.index = -1;
      this.builder = new SubscriberSpecBuilder(this);
    }
    SubscriberSpecBuilder builder;
    int index;
    public N and() {
      return (N) ChannelSpecFluentImpl.this.setToSubscribers(index,builder.build());
    }
    public N endSubscriber() {
      return and();
    }
    
  }
  
}
